# -*- coding: utf-8 -*-
"""
@copyright: (C) 2019 Surface Concept GmbH

Test statistics pipe.

"""

def test_statistics_pipe():
    """ Performs 1 measurement and prints statistics data, afterwards. """
    import scTDC
    
    device = scTDC.Device(autoinit=False)
    retcode, errmsg = device.initialize()
    if retcode < 0:
        print("Error during initialization : ({}) {}".format(errmsg, retcode))
        return
    
    pipeid, pipe = device.add_statistics_pipe()

    
    print("Starting a measurement")
    retcode, errmsg = device.do_measurement(time_ms=100, synchronous=True)
    if retcode < 0:
        print("Error while starting measurement : ({}) {}".format(
            errmsg, retcode))
    print("Finished measurements")
    
    stat_data = pipe.get_buffer_copy()
    print("non-zero raw counts by channel:")
    for i in range(16):
        r = stat_data.counts_read[i]
        if r > 0:
            print(" {:2} {:15}".format(i, r))
    maxcounts = max([stat_data.counts_read[i] for i in range(16)])
    print("highest of the raw counts :", maxcounts)
    print("events found :", stat_data.events_found[0])
    if maxcounts > 0:
        print("ratio of found events to highest raw count : {:.3g}".format( 
              stat_data.events_found[0]/maxcounts))

    
    device.deinitialize()

if __name__ == "__main__":
    test_statistics_pipe()
